'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const React = require('react');
const reactPopopo = require('react-popopo');
const styled = require('styled-components');
const uuid = require('uuid');
const ReactDOM = require('react-dom');
const container = require('react-trello-ts-smooth-dnd');
const zustand = require('zustand');

function _interopDefaultCompat (e) { return e && typeof e === 'object' && 'default' in e ? e.default : e; }

const React__default = /*#__PURE__*/_interopDefaultCompat(React);
const styled__default = /*#__PURE__*/_interopDefaultCompat(styled);
const ReactDOM__default = /*#__PURE__*/_interopDefaultCompat(ReactDOM);
const container__default = /*#__PURE__*/_interopDefaultCompat(container);

const GlobalStyle = styled.createGlobalStyle`
  .comPlainTextContentEditable {
    -webkit-user-modify: read-write-plaintext-only;
    cursor: text;
  }

  .comPlainTextContentEditable--has-placeholder::before {
    content: attr(placeholder);
    opacity: 0.5;
    color: inherit;
    cursor: text;
  }

  .react_trello_dragClass {
    transform: rotate(3deg);
  }

  .react_trello_dragLaneClass {
    transform: rotate(3deg);
  }

  .icon-overflow-menu-horizontal:before {
    content: "\\E91F";
  }
  .icon-lg, .icon-sm {
    color: #798d99;
  }
  .icon-lg {
    height: 32px;
    font-size: 16px;
    line-height: 32px;
    width: 32px;
  }
`;
const CustomPopoverContainer = styled__default(reactPopopo.PopoverContainer)`
  position: absolute;
  right: 10px;
  flex-flow: column nowrap;
`;
const CustomPopoverContent = styled__default(reactPopopo.PopoverContent)`
  visibility: hidden;
  margin-top: -5px;
  opacity: 0;
  position: absolute;
  z-index: 10;
  box-shadow: 2px 2px 8px rgba(0, 0, 0, 0.3);
  transition: all 0.3s ease 0ms;
  border-radius: 3px;
  min-width: 7em;
  flex-flow: column nowrap;
  background-color: #fff;
  color: #000;
  padding: 5px;
  left: 50%;
  transform: translateX(-50%);
  ${(props) => props.active && `
    visibility: visible;
    opacity: 1;
    transition-delay: 100ms;
  `} &::before {
    visibility: hidden;
  }
  a {
    color: rgba(255, 255, 255, 0.56);
    padding: 0.5em 1em;
    margin: 0;
    text-decoration: none;
    &:hover {
      background-color: #00bcd4 !important;
      color: #37474f;
    }
  }
`;
const BoardWrapper = styled__default.div`
  background-color: #3179ba;
  overflow-y: hidden;
  padding: 5px;
  color: #393939;
  display: flex;
  flex-direction: row;
  align-items: flex-start;
  height: 100vh;
`;
const Header = styled__default.header`
  margin-bottom: 10px;
  display: flex;
  flex-direction: row;
  align-items: flex-start;
`;
const Section = styled__default.section`
  background-color: #e3e3e3;
  border-radius: 3px;
  margin: 5px 5px;
  position: relative;
  padding: 10px;
  display: inline-flex;
  height: auto;
  max-height: 90%;
  flex-direction: column;
`;
const LaneHeader$1 = styled__default(Header)`
  margin-bottom: 0px;
  ${(props) => props.editLaneTitle && styled.css`
      padding: 0px;
      line-height: 30px;
    `} ${(props) => !props.editLaneTitle && styled.css`
      padding: 0px 5px;
    `};
`;
const LaneFooter$1 = styled__default.div`
  display: flex;
  justify-content: center;
  align-items: center;
  width: 100%;
  position: relative;
  height: 10px;
`;
const ScrollableLane = styled__default.div`
  flex: 1;
  overflow-y: auto;
  min-width: 250px;
  overflow-x: hidden;
  align-self: center;
  max-height: 90vh;
  margin-top: 10px;
  flex-direction: column;
  justify-content: space-between;
`;
const Title = styled__default.span`
  font-weight: bold;
  font-size: 15px;
  line-height: 18px;
  cursor: ${(props) => props.draggable ? "grab" : "auto"};
  width: 70%;
`;
const RightContent = styled__default.span`
  width: 38%;
  text-align: right;
  padding-right: 10px;
  font-size: 13px;
`;
const CardWrapper = styled__default.article`
  border-radius: 3px;
  border-bottom: 1px solid #ccc;
  background-color: #fff;
  position: relative;
  padding: 10px;
  cursor: pointer;
  max-width: 250px;
  margin-bottom: 7px;
  min-width: 230px;
`;
const MovableCardWrapper = styled__default(CardWrapper)`
  &:hover {
    background-color: #f0f0f0;
    color: #000;
  }
`;
const CardHeader = styled__default(Header)`
  border-bottom: 1px solid #eee;
  padding-bottom: 6px;
  color: #000;
`;
const CardTitle = styled__default(Title)`
  font-size: 14px;
`;
const CardRightContent = styled__default(RightContent)`
  font-size: 10px;
`;
const Detail = styled__default.div`
  font-size: 12px;
  color: #4d4d4d;
  white-space: pre-wrap;
`;
const Footer = styled__default.div`
  border-top: 1px solid #eee;
  padding-top: 6px;
  text-align: right;
  display: flex;
  justify-content: flex-end;
  flex-direction: row;
  flex-wrap: wrap;
`;
const TagSpan = styled__default.span`
  padding: 2px 3px;
  border-radius: 3px;
  margin: 2px 5px;
  font-size: 70%;
`;
const AddCardLink$1 = styled__default.a`
  border-radius: 0 0 3px 3px;
  color: #838c91;
  display: block;
  padding: 5px 2px;
  margin-top: 10px;
  position: relative;
  text-decoration: none;
  cursor: pointer;

  &:hover {
    //background-color: #cdd2d4;
    color: #4d4d4d;
    text-decoration: underline;
  }
`;
const LaneTitle = styled__default.div`
  font-size: 15px;
  width: 268px;
  height: auto;
`;
const LaneSection = styled__default.section`
  background-color: #2b6aa3;
  border-radius: 3px;
  margin: 5px;
  position: relative;
  padding: 5px;
  display: inline-flex;
  height: auto;
  flex-direction: column;
`;
const NewLaneSection$1 = styled__default(LaneSection)`
  width: 200px;
`;
const NewLaneButtons = styled__default.div`
  margin-top: 10px;
`;
const CardForm = styled__default.div`
  background-color: #e3e3e3;
`;
const InlineInput$1 = styled__default.textarea`
  overflow-x: hidden; /* for Firefox (issue #5) */
  word-wrap: break-word;
  min-height: 18px;
  max-height: 112px; /* optional, but recommended */
  resize: none;
  width: 100%;
  height: 18px;
  font-size: inherit;
  font-weight: inherit;
  line-height: inherit;
  text-align: inherit;
  background-color: transparent;
  box-shadow: none;
  box-sizing: border-box;
  border-radius: 3px;
  border: 0;
  padding: 0 8px;
  outline: 0;
  ${(props) => props.border && styled.css`
      &:focus {
        box-shadow: inset 0 0 0 2px #0079bf;
      }
    `} &:focus {
    background-color: white;
  }
  ${(props) => props.resize && styled.css`
      resize: ${props.resize};
    `};
`;

const AddCardLink = ({
  onClick,
  t
}) => /* @__PURE__ */ React__default.createElement(AddCardLink$1, { onClick }, t("Click to add card"));

const DeleteWrapper = styled__default.div`
  text-align: center;
  position: absolute;
  top: -1px;
  right: 2px;
  cursor: pointer;
`;
const GenDelButton = styled__default.button`
  transition: all 0.5s ease;
  display: inline-block;
  border: none;
  font-size: 15px;
  height: 15px;
  padding: 0;
  margin-top: 5px;
  text-align: center;
  width: 15px;
  background: inherit;
  cursor: pointer;
`;
const DelButton = styled__default.button`
  transition: all 0.5s ease;
  display: inline-block;
  border: none;
  font-size: 8px;
  height: 15px;
  line-height: 1px;
  margin: 0 0 8px;
  padding: 0;
  text-align: center;
  width: 15px;
  background: inherit;
  cursor: pointer;
  opacity: 0;
  ${MovableCardWrapper}:hover & {
    opacity: 1;
  }
`;
const MenuButton = styled__default.button`
  transition: all 0.5s ease;
  display: inline-block;
  border: none;
  outline: none;
  font-size: 16px;
  font-weight: bold;
  height: 15px;
  line-height: 1px;
  margin: 0 0 8px;
  padding: 0;
  text-align: center;
  width: 15px;
  background: inherit;
  cursor: pointer;
`;
const LaneMenuHeader = styled__default.div`
    position: relative;
    margin-bottom: 4px;
    text-align: center;
`;
const LaneMenuContent = styled__default.div`
    overflow-x: hidden;
    overflow-y: auto;
    padding: 0 12px 12px;
`;
const LaneMenuItem = styled__default.div`
    cursor: pointer;
    display: block;
    font-weight: 700;
    padding: 6px 12px;
    position: relative;
    margin: 0 -12px;
    text-decoration: none;

    &:hover {
      background-color: #3179BA;
      color: #fff;
    }
`;
const LaneMenuTitle = styled__default.span`
    box-sizing: border-box;
    color: #6b808c;
    display: block;
    line-height: 30px;
    border-bottom: 1px solid rgba(9,45,66,.13);
    margin: 0 6px;
    overflow: hidden;
    padding: 0 32px;
    position: relative;
    text-overflow: ellipsis;
    white-space: nowrap;
    z-index: 1;
`;
styled__default.span`
  position: relative;
  display: inline-block;
  width: 4px;
  height: 4px;
  opacity: 1;
  overflow: hidden;
  border: 1px solid #83bd42;
  border-radius: 50%;
  padding: 4px;
  background-color: #83bd42;

  ${CardWrapper}:hover & {
    opacity: 1;
  }

  &:hover::before,
  &:hover::after {
    background: red;
  }

  &:before,
  &:after {
    content: '';
    position: absolute;
    height: 2px;
    width: 60%;
    top: 45%;
    left: 20%;
    background: #fff;
    border-radius: 5px;
  }

  &:before {
    -webkit-transform: rotate(45deg);
    -moz-transform: rotate(45deg);
    -o-transform: rotate(45deg);
    transform: rotate(45deg);
  }

  &:after {
    -webkit-transform: rotate(-45deg);
    -moz-transform: rotate(-45deg);
    -o-transform: rotate(-45deg);
    transform: rotate(-45deg);
  }
`;
const ExpandCollapseBase = styled__default.span`
  width: 36px;
  margin: 0 auto;
  font-size: 14px;
  position: relative;
  cursor: pointer;
`;
const CollapseBtn = styled__default(ExpandCollapseBase)`
  &:before {
    content: '';
    position: absolute;
    top: 0;
    left: 0;
    border-bottom: 7px solid #444;
    border-left: 7px solid transparent;
    border-right: 7px solid transparent;
    border-radius: 6px;
  }
  &:after {
    content: '';
    position: absolute;
    left: 4px;
    top: 4px;
    border-bottom: 3px solid #e3e3e3;
    border-left: 3px solid transparent;
    border-right: 3px solid transparent;
  }
`;
const ExpandBtn = styled__default(ExpandCollapseBase)`
  &:before {
    content: '';
    position: absolute;
    top: 0;
    left: 0;
    border-top: 7px solid #444;
    border-left: 7px solid transparent;
    border-right: 7px solid transparent;
    border-radius: 6px;
  }
  &:after {
    content: '';
    position: absolute;
    left: 4px;
    top: 0px;
    border-top: 3px solid #e3e3e3;
    border-left: 3px solid transparent;
    border-right: 3px solid transparent;
  }
`;
const AddButton = styled__default.button`
  background: #5aac44;
  color: #fff;
  transition: background 0.3s ease;
  min-height: 32px;
  padding: 4px 16px;
  vertical-align: top;
  margin-top: 0;
  margin-right: 8px;
  font-weight: bold;
  border-radius: 3px;
  font-size: 14px;
  cursor: pointer;
  margin-bottom: 0;
`;
const CancelButton = styled__default.button`
  background: #999999;
  color: #fff;
  transition: background 0.3s ease;
  min-height: 32px;
  padding: 4px 16px;
  vertical-align: top;
  margin-top: 0;
  font-weight: bold;
  border-radius: 3px;
  font-size: 14px;
  cursor: pointer;
  margin-bottom: 0;
`;
const AddLaneLink = styled__default.button`
  background: #2b6aa3;
  border: none;
  color: #fff;
  transition: background 0.3s ease;
  min-height: 32px;
  padding: 4px 16px;
  vertical-align: top;
  margin-top: 0;
  margin-right: 0px;
  border-radius: 4px;
  font-size: 13px;
  cursor: pointer;
  margin-bottom: 0;
`;

const DeleteButton = ({
  ...rest
}) => {
  return /* @__PURE__ */ React__default.createElement(DeleteWrapper, { ...rest }, /* @__PURE__ */ React__default.createElement(DelButton, null, "\u2716"));
};

const EditableLabel = ({
  autoFocus = false,
  inline = false,
  onChange = () => {
  },
  placeholder = "",
  value = "",
  children
}) => {
  const [labelText, setLabelText] = React.useState("");
  const divRef = React.createRef();
  React.useEffect(() => {
    if (autoFocus) {
      divRef.current.focus();
    }
  });
  const getClassName = () => {
    const placeholder2 = labelText === "" ? "comPlainTextContentEditable--has-placeholder" : "";
    return `comPlainTextContentEditable ${placeholder2}`;
  };
  const onPaste = (event) => {
    event.preventDefault();
    navigator.clipboard.writeText(event.clipboardData.getData("text"));
  };
  const onBlur = () => {
    onChange(labelText);
  };
  const onKeyDown = (event) => {
    if (event.key === "Enter") {
      event.preventDefault();
      onChange(labelText);
      divRef.current.blur();
    }
    if (event.key === "Escape") {
      divRef.current.textContent = labelText;
      event.preventDefault();
      event.stopPropagation();
    }
  };
  const onTextChange = (event) => {
    const value2 = event.currentTarget.innerText;
    setLabelText(value2);
  };
  return /* @__PURE__ */ React__default.createElement(
    "div",
    {
      ref: divRef,
      contentEditable: "true",
      className: getClassName(),
      onPaste,
      onBlur,
      onInput: onTextChange,
      onKeyDown,
      placeholder
    }
  );
};

const assignedElements = /* @__PURE__ */ new Map();
function assign(ta, options) {
  if (!ta || !ta.nodeName || ta.nodeName !== "TEXTAREA" || assignedElements.has(ta))
    return;
  let previousHeight = null;
  function cacheScrollTops(el) {
    const arr = [];
    while (el && el.parentNode && el.parentNode instanceof Element) {
      if (el.parentNode.scrollTop) {
        arr.push([el.parentNode, el.parentNode.scrollTop]);
      }
      el = el.parentNode;
    }
    return () => arr.forEach(([node, scrollTop]) => {
      node.style.scrollBehavior = "auto";
      node.scrollTop = scrollTop;
      node.style.scrollBehavior = null;
    });
  }
  const computed = window.getComputedStyle(ta);
  function setHeight({
    restoreTextAlign = null,
    testForHeightReduction = true
  } = {}) {
    const initialOverflowY = computed.overflowY;
    if (ta.scrollHeight === 0) {
      return;
    }
    if (computed.resize === "vertical") {
      ta.style.resize = "none";
    } else if (computed.resize === "both") {
      ta.style.resize = "horizontal";
    }
    let restoreScrollTops;
    if (testForHeightReduction) {
      restoreScrollTops = cacheScrollTops(ta);
      ta.style.height = "";
    }
    let newHeight;
    if (computed.boxSizing === "content-box") {
      newHeight = ta.scrollHeight - (parseFloat(computed.paddingTop) + parseFloat(computed.paddingBottom));
    } else {
      newHeight = ta.scrollHeight + parseFloat(computed.borderTopWidth) + parseFloat(computed.borderBottomWidth);
    }
    if (computed.maxHeight !== "none" && newHeight > parseFloat(computed.maxHeight)) {
      if (computed.overflowY === "hidden") {
        ta.style.overflow = "scroll";
      }
      newHeight = parseFloat(computed.maxHeight);
    } else if (computed.overflowY !== "hidden") {
      ta.style.overflow = "hidden";
    }
    ta.style.height = newHeight + "px";
    if (restoreTextAlign) {
      ta.style.textAlign = restoreTextAlign;
    }
    if (restoreScrollTops) {
      restoreScrollTops();
    }
    if (previousHeight !== newHeight) {
      ta.dispatchEvent(new Event("autosize:resized", { bubbles: true }));
      previousHeight = newHeight;
    }
    if (initialOverflowY !== computed.overflow && !restoreTextAlign) {
      const textAlign = computed.textAlign;
      if (computed.overflow === "hidden") {
        ta.style.textAlign = textAlign === "start" ? "end" : "start";
      }
      setHeight({
        restoreTextAlign: textAlign,
        testForHeightReduction: true
      });
    }
  }
  function fullSetHeight() {
    setHeight({
      testForHeightReduction: true,
      restoreTextAlign: null
    });
  }
  const handleInput = (() => {
    let previousValue = ta.value;
    return () => {
      setHeight({
        // if previousValue is '', check for height shrinkage because the placeholder may be taking up space instead
        // if new value is merely appending to previous value, skip checking for height deduction
        testForHeightReduction: previousValue === "" || !ta.value.startsWith(previousValue),
        restoreTextAlign: null
      });
      previousValue = ta.value;
    };
  })();
  const destroy2 = /* @__PURE__ */ ((style) => function destroyAutosize() {
    ta.removeEventListener("autosize:destroy", destroy2);
    ta.removeEventListener("autosize:update", fullSetHeight);
    ta.removeEventListener("input", handleInput);
    window.removeEventListener("resize", fullSetHeight);
    Object.keys(style).forEach(
      (key) => ta.style[key] = style[key]
    );
    assignedElements.delete(ta);
  })({
    height: ta.style.height,
    resize: ta.style.resize,
    textAlign: ta.style.textAlign,
    overflowY: ta.style.overflowY,
    overflowX: ta.style.overflowX,
    wordWrap: ta.style.wordWrap
  });
  ta.addEventListener("autosize:destroy", destroy2);
  ta.addEventListener("autosize:update", fullSetHeight);
  ta.addEventListener("input", handleInput);
  window.addEventListener("resize", fullSetHeight);
  ta.style.overflowX = "hidden";
  ta.style.wordWrap = "break-word";
  assignedElements.set(ta, {
    destroy: destroy2,
    update: fullSetHeight
  });
  fullSetHeight();
}
function destroy(ta) {
  const methods = assignedElements.get(ta);
  if (methods) {
    methods.destroy();
  }
}
function update(ta) {
  const methods = assignedElements.get(ta);
  if (methods) {
    methods.update();
  }
}
let autosize;
if (typeof window === "undefined") {
  const noop = (el) => el;
  autosize = noop;
  autosize.destroy = noop;
  autosize.update = noop;
} else {
  const autosizeFunction = (el, options) => {
    if (el) {
      const isArrayLike = (obj) => obj && typeof obj.length === "number";
      if (isArrayLike(el) && el.length) {
        Array.prototype.forEach.call(
          el,
          (x) => assign(x)
        );
      } else {
        assign(el);
      }
    }
    return el;
  };
  autosizeFunction.destroy = (el) => {
    if (el) {
      const isArrayLike = (obj) => obj && typeof obj.length === "number";
      if (isArrayLike(el) && el.length) {
        Array.prototype.forEach.call(el, destroy);
      } else {
        destroy(el);
      }
    }
    return el;
  };
  autosizeFunction.update = (el) => {
    if (el) {
      const isArrayLike = (obj) => obj && typeof obj.length === "number";
      if (isArrayLike(el) && el.length) {
        Array.prototype.forEach.call(el, update);
      } else {
        update(el);
      }
    }
    return el;
  };
  autosize = autosizeFunction;
}
const autosize$1 = autosize;

const InlineInput = ({
  autoFocus = false,
  border = false,
  onSave = () => {
  },
  onCancel = () => {
  },
  placeholder = "",
  value = "",
  resize = "none"
}) => {
  const [inputValue, setInputValue] = React.useState(value);
  const inputRef = React.useRef(null);
  const onFocus = (e) => e.target.select();
  const onMouseDown = (e) => {
    if (document.activeElement !== e.target) {
      e.preventDefault();
      inputRef.current.focus();
    }
  };
  const onBlur = () => {
    updateValue();
  };
  const onKeyDown = (e) => {
    if (e.key === "Enter") {
      inputRef.current.blur();
      e.preventDefault();
    }
    if (e.key === "Escape") {
      setValue(value);
      inputRef.current.blur();
      e.preventDefault();
    }
    if (e.key === "Tab") {
      if (inputValue.length === 0) {
        onCancel();
      }
      inputRef.current.blur();
      e.preventDefault();
    }
  };
  const getValue = () => inputRef.current.value || "";
  const setValue = (newValue) => {
    if (inputRef.current) {
      inputRef.current.value = newValue;
    }
  };
  const updateValue = () => {
    if (getValue() !== value) {
      onSave(getValue());
    }
  };
  const setRef = (ref) => {
    inputRef.current = ref;
    if (resize !== "none") {
      autosize$1(inputRef.current);
    }
  };
  React.useEffect(() => {
    setInputValue(value);
  }, [value]);
  return /* @__PURE__ */ React__default.createElement(
    InlineInput$1,
    {
      ref: setRef,
      border,
      onMouseDown,
      onFocus,
      onBlur,
      onKeyDown,
      placeholder: value.length === 0 ? void 0 : placeholder,
      defaultValue: value,
      autoComplete: "off",
      autoCorrect: "off",
      autoCapitalize: "off",
      spellCheck: "false",
      rows: 1,
      autoFocus
    }
  );
};

const Tag = ({
  title,
  color,
  bgcolor,
  tagStyle,
  ...otherProps
}) => {
  const style = {
    color: color || "white",
    backgroundColor: bgcolor || "orange",
    ...tagStyle
  };
  return /* @__PURE__ */ React__default.createElement(TagSpan, { style, ...otherProps }, title);
};

const Card = ({
  onDelete,
  onChange,
  id,
  onClick,
  style,
  className,
  description,
  label,
  t,
  tags,
  title,
  cardDraggable,
  editable,
  showDeleteButton,
  tagStyle
}) => {
  const _onDelete = (e) => {
    onDelete();
    e.stopPropagation();
  };
  const updateCard = (card) => {
    onChange({ ...card, id });
  };
  return /* @__PURE__ */ React__default.createElement(
    MovableCardWrapper,
    {
      "data-id": id,
      onClick,
      style,
      className
    },
    /* @__PURE__ */ React__default.createElement(CardHeader, null, /* @__PURE__ */ React__default.createElement(CardTitle, { draggable: cardDraggable }, editable ? /* @__PURE__ */ React__default.createElement(
      InlineInput,
      {
        value: title,
        border: true,
        placeholder: t("placeholder.title"),
        resize: "vertical",
        onSave: (value) => updateCard({ title: value })
      }
    ) : title), /* @__PURE__ */ React__default.createElement(CardRightContent, null, editable ? /* @__PURE__ */ React__default.createElement(
      InlineInput,
      {
        value: label,
        border: true,
        placeholder: t("placeholder.label"),
        resize: "vertical",
        onSave: (value) => updateCard({ label: value })
      }
    ) : label), showDeleteButton && /* @__PURE__ */ React__default.createElement(DeleteButton, { onClick: _onDelete })),
    /* @__PURE__ */ React__default.createElement(Detail, null, editable ? /* @__PURE__ */ React__default.createElement(
      InlineInput,
      {
        value: description,
        border: true,
        placeholder: t("placeholder.description"),
        resize: "vertical",
        onSave: (value) => updateCard({ description: value })
      }
    ) : description),
    tags && tags.length > 0 && /* @__PURE__ */ React__default.createElement(Footer, null, tags.map((tag) => /* @__PURE__ */ React__default.createElement(Tag, { key: tag.title, ...tag, tagStyle })))
  );
};

const LaneFooter = ({
  onClick,
  onKeyDown,
  collapsed
}) => /* @__PURE__ */ React__default.createElement(LaneFooter$1, { onClick, onKeyDown }, collapsed ? /* @__PURE__ */ React__default.createElement(ExpandBtn, null) : /* @__PURE__ */ React__default.createElement(CollapseBtn, null));

const LaneMenu = ({
  t,
  onDelete
}) => /* @__PURE__ */ React__default.createElement(
  reactPopopo.Popover,
  {
    position: "bottom",
    PopoverContainer: CustomPopoverContainer,
    PopoverContent: CustomPopoverContent,
    trigger: /* @__PURE__ */ React__default.createElement(MenuButton, null, "\u22EE")
  },
  /* @__PURE__ */ React__default.createElement(LaneMenuHeader, null, /* @__PURE__ */ React__default.createElement(LaneMenuTitle, null, t("Lane actions")), /* @__PURE__ */ React__default.createElement(DeleteWrapper, null, /* @__PURE__ */ React__default.createElement(GenDelButton, null, "\u2716"))),
  /* @__PURE__ */ React__default.createElement(LaneMenuContent, null, /* @__PURE__ */ React__default.createElement(LaneMenuItem, { onClick: onDelete }, t("Delete lane")))
);

const LaneHeader = ({
  updateTitle = () => {
  },
  canAddLanes = false,
  onDelete,
  onDoubleClick,
  editLaneTitle,
  label,
  title,
  titleStyle,
  labelStyle,
  t,
  laneDraggable
}) => {
  return /* @__PURE__ */ React__default.createElement(LaneHeader$1, { onDoubleClick, editLaneTitle }, /* @__PURE__ */ React__default.createElement(Title, { draggable: laneDraggable, style: titleStyle }, editLaneTitle ? /* @__PURE__ */ React__default.createElement(
    InlineInput,
    {
      value: title,
      border: true,
      placeholder: t("placeholder.title"),
      resize: "vertical",
      onSave: updateTitle
    }
  ) : title), label && /* @__PURE__ */ React__default.createElement(RightContent, null, /* @__PURE__ */ React__default.createElement("span", { style: labelStyle }, label)), canAddLanes && /* @__PURE__ */ React__default.createElement(LaneMenu, { t, onDelete }));
};

const keyframeAnimation = styled.keyframes`
    0% {
      transform: scale(1);
    }
    20% {
      transform: scale(1, 2.2);
    }
    40% {
      transform: scale(1);
    }
`;
const LoaderDiv = styled__default.div`
  text-align: center;
  margin: 15px 0;
`;
const LoadingBar = styled__default.div`
  display: inline-block;
  margin: 0 2px;
  width: 4px;
  height: 18px;
  border-radius: 4px;
  animation: ${keyframeAnimation} 1s ease-in-out infinite;
  background-color: #777;

  &:nth-child(1) {
    animation-delay: 0.0001s;
  }
  &:nth-child(2) {
    animation-delay: 0.09s;
  }
  &:nth-child(3) {
    animation-delay: 0.18s;
  }
  &:nth-child(4) {
    animation-delay: 0.27s;
  }
`;

const Loader = () => /* @__PURE__ */ React__default.createElement(LoaderDiv, null, /* @__PURE__ */ React__default.createElement(LoadingBar, null), /* @__PURE__ */ React__default.createElement(LoadingBar, null), /* @__PURE__ */ React__default.createElement(LoadingBar, null), /* @__PURE__ */ React__default.createElement(LoadingBar, null));

const NewCardForm = ({
  laneId,
  onCancel,
  onAdd,
  t
}) => {
  const [formState, setFormState] = React.useState();
  const handleAdd = () => {
    onAdd({ ...formState, laneId });
  };
  const updateField = (field, value) => {
    setFormState({ ...formState, [field]: value });
  };
  return /* @__PURE__ */ React__default.createElement(CardForm, null, /* @__PURE__ */ React__default.createElement(CardWrapper, null, /* @__PURE__ */ React__default.createElement(CardHeader, null, /* @__PURE__ */ React__default.createElement(CardTitle, null, /* @__PURE__ */ React__default.createElement(
    EditableLabel,
    {
      placeholder: t("placeholder.title"),
      onChange: (val) => updateField("title", val),
      autoFocus: true
    }
  )), /* @__PURE__ */ React__default.createElement(CardRightContent, null, /* @__PURE__ */ React__default.createElement(
    EditableLabel,
    {
      placeholder: t("placeholder.label"),
      onChange: (val) => updateField("label", val)
    }
  ))), /* @__PURE__ */ React__default.createElement(Detail, null, /* @__PURE__ */ React__default.createElement(
    EditableLabel,
    {
      placeholder: t("placeholder.description"),
      onChange: (val) => updateField("description", val)
    }
  ))), /* @__PURE__ */ React__default.createElement(AddButton, { onClick: handleAdd }, t("button.Add card")), /* @__PURE__ */ React__default.createElement(CancelButton, { onClick: onCancel }, t("button.Cancel")));
};

const NewLaneTitleEditor = ({
  autoFocus = false,
  border = false,
  onCancel = () => {
  },
  onSave = () => {
  },
  placeholder = "",
  resize = "none",
  value = "",
  inputRef
}) => {
  const [inputValue, setInputValue] = React.useState(value);
  const onKeyDown = (e) => {
    if (e.key === "Enter") {
      inputRef.current.blur();
      saveValue();
      e.preventDefault();
    }
    if (e.key === "Escape") {
      setInputValue(value);
      inputRef.current.blur();
      cancel();
      e.preventDefault();
    }
    if (e.key === "Tab") {
      if (inputValue.length === 0) {
        onCancel();
      }
      inputRef.current.blur();
      e.preventDefault();
    }
  };
  const setRef = (ref) => {
    inputRef.current = ref;
    if (resize !== "none") {
      autosize$1(inputRef.current);
    }
  };
  const cancel = () => {
    setInputValue("");
    onCancel();
    inputRef.current.blur();
  };
  const saveValue = () => {
    if (inputValue !== value) {
      onSave(inputValue);
    }
  };
  return /* @__PURE__ */ React__default.createElement(
    InlineInput$1,
    {
      style: { resize },
      ref: setRef,
      border,
      onKeyDown,
      placeholder: inputValue.length === 0 ? void 0 : placeholder,
      defaultValue: value,
      rows: 3,
      autoFocus
    }
  );
};

const NewLaneForm = ({
  onAdd,
  onCancel,
  t
}) => {
  const titleRef = React.useRef();
  const handleSubmit = () => {
    onAdd({
      id: uuid.v1(),
      title: titleRef.current.value
    });
  };
  return /* @__PURE__ */ React__default.createElement(Section, null, /* @__PURE__ */ React__default.createElement(LaneTitle, null, /* @__PURE__ */ React__default.createElement(
    NewLaneTitleEditor,
    {
      inputRef: titleRef,
      placeholder: t("placeholder.title"),
      onCancel,
      onSave: handleSubmit,
      resize: "vertical",
      border: true,
      autoFocus: true
    }
  )), /* @__PURE__ */ React__default.createElement(NewLaneButtons, null, /* @__PURE__ */ React__default.createElement(AddButton, { onClick: handleSubmit }, t("button.Add lane")), /* @__PURE__ */ React__default.createElement(CancelButton, { onClick: onCancel }, t("button.Cancel"))));
};

const NewLaneSection = ({ t, onClick }) => /* @__PURE__ */ React__default.createElement(NewLaneSection$1, null, /* @__PURE__ */ React__default.createElement(AddLaneLink, { onClick }, t("Add another lane")));

const DefaultComponents = {
  __proto__: null,
  AddCardLink: AddCardLink,
  BoardWrapper: BoardWrapper,
  Card: Card,
  GlobalStyle: GlobalStyle,
  LaneFooter: LaneFooter,
  LaneHeader: LaneHeader,
  Loader: Loader,
  NewCardForm: NewCardForm,
  NewLaneForm: NewLaneForm,
  NewLaneSection: NewLaneSection,
  ScrollableLane: ScrollableLane,
  Section: Section
};

container__default.dropHandler = container.dropHandlers.reactDropHandler().handler;
container__default.wrapChild = (p) => p;
class Container extends React.Component {
  containerDiv;
  prevContainer;
  container;
  constructor(props) {
    super(props);
    this.getContainerOptions = this.getContainerOptions.bind(this);
    this.setRef = this.setRef.bind(this);
    this.prevContainer = null;
  }
  componentDidMount() {
    this.containerDiv = this.containerDiv || ReactDOM__default.findDOMNode(this);
    this.prevContainer = this.containerDiv;
    this.container = container__default(this.containerDiv, this.getContainerOptions());
  }
  componentWillUnmount() {
    this.container.dispose();
    this.container = null;
  }
  componentDidUpdate() {
    this.containerDiv = this.containerDiv || ReactDOM__default.findDOMNode(this);
    if (this.containerDiv) {
      if (this.prevContainer && this.prevContainer !== this.containerDiv) {
        this.container.dispose();
        this.container = container__default(
          this.containerDiv,
          this.getContainerOptions()
        );
        this.prevContainer = this.containerDiv;
      }
    }
  }
  render() {
    if (this.props.render) {
      return this.props.render(this.setRef);
    }
    return /* @__PURE__ */ React__default.createElement("div", { style: this.props.style, ref: this.setRef }, this.props.children);
  }
  setRef(element) {
    this.containerDiv = element;
  }
  getContainerOptions() {
    const functionProps = {};
    if (this.props.onDragStart) {
      functionProps.onDragStart = (...p) => this.props.onDragStart(...p);
    }
    if (this.props.onDragEnd) {
      functionProps.onDragEnd = (...p) => this.props.onDragEnd(...p);
    }
    if (this.props.onDrop) {
      functionProps.onDrop = (...p) => this.props.onDrop(...p);
    }
    if (this.props.getChildPayload) {
      functionProps.getChildPayload = (...p) => this.props.getChildPayload(...p);
    }
    if (this.props.shouldAnimateDrop) {
      functionProps.shouldAnimateDrop = (...p) => this.props.shouldAnimateDrop(...p);
    }
    if (this.props.shouldAcceptDrop) {
      functionProps.shouldAcceptDrop = (...p) => this.props.shouldAcceptDrop(...p);
    }
    if (this.props.onDragEnter) {
      functionProps.onDragEnter = (...p) => this.props.onDragEnter(...p);
    }
    if (this.props.onDragLeave) {
      functionProps.onDragLeave = (...p) => this.props.onDragLeave(...p);
    }
    if (this.props.render) {
      functionProps.render = (...p) => this.props.render(...p);
    }
    if (this.props.onDropReady) {
      functionProps.onDropReady = (...p) => this.props.onDropReady(...p);
    }
    if (this.props.getGhostParent) {
      functionProps.getGhostParent = (...p) => this.props.getGhostParent(...p);
    }
    return Object.assign({}, this.props, functionProps);
  }
}

const { wrapperClass } = container.constants;
class Draggable extends React.Component {
  render() {
    if (this.props.render) {
      return React__default.cloneElement(this.props.render(), {
        className: wrapperClass
      });
    }
    const clsName = this.props.className ? `${this.props.className} ` : "";
    return /* @__PURE__ */ React__default.createElement("div", { ...this.props, className: `${clsName}${wrapperClass}` }, this.props.children);
  }
}

const store = zustand.create()((set) => {
  const findLaneIndex = (state, laneId, errorMessage = "Lane not found") => {
    const laneIndex = state.data.lanes.findIndex((l) => l.id === laneId);
    if (laneIndex === -1) {
      throw new Error(errorMessage);
    }
    return laneIndex;
  };
  const updateLaneById = (state, laneId, updates) => {
    const laneIndex = findLaneIndex(state, laneId);
    const updatedLanes = [...state.data.lanes];
    updatedLanes[laneIndex] = { ...updatedLanes[laneIndex], ...updates };
    return { data: { ...state.data, lanes: updatedLanes } };
  };
  return {
    data: { lanes: [] },
    initializeLanes: (lanes) => set((state) => ({
      data: {
        ...state.data,
        lanes: lanes.map((lane) => ({
          ...lane,
          currentPage: 1,
          cards: lane.cards?.map((c) => ({ ...c, laneId: lane.id }))
        }))
      }
    })),
    refreshBoard: (lanes = []) => set(() => ({ data: { lanes } })),
    addCard: (card, laneId, index) => set((state) => {
      const laneIndex = findLaneIndex(state, laneId);
      const lane = state.data.lanes[laneIndex];
      let updatedCards;
      if (index === void 0) {
        updatedCards = [...lane.cards, card];
      } else {
        updatedCards = [...lane.cards];
        updatedCards[index] = card;
      }
      return updateLaneById(state, laneId, { cards: updatedCards });
    }),
    removeCard: (laneId, cardId) => set((state) => {
      const laneIndex = findLaneIndex(state, laneId);
      const lane = state.data.lanes[laneIndex];
      const updatedCards = lane.cards.filter((c) => c.id !== cardId);
      return updateLaneById(state, laneId, { cards: updatedCards });
    }),
    moveCard: (fromLaneId, toLaneId, cardId, index) => set((state) => {
      const fromLaneIndex = state.data.lanes.findIndex(
        (l) => l.id === fromLaneId
      );
      if (fromLaneIndex === -1) {
        throw new Error("fromLane not found");
      }
      const toLaneIndex = state.data.lanes.findIndex(
        (l) => l.id === toLaneId
      );
      if (toLaneIndex === -1) {
        throw new Error("toLane not found");
      }
      const fromLane = state.data.lanes[fromLaneIndex];
      const toLane = state.data.lanes[toLaneIndex];
      const cardIndex = fromLane.cards.findIndex((c) => c.id === cardId);
      if (cardIndex === -1) {
        return state;
      }
      const card = fromLane.cards[cardIndex];
      const newCard = { ...card, laneId: toLaneId };
      const updatedFromCards = fromLane.cards.filter(
        (_, i) => i !== cardIndex
      );
      let updatedToCards;
      if (index !== void 0) {
        updatedToCards = [...toLane.cards];
        updatedToCards.splice(index, 0, newCard);
      } else {
        updatedToCards = [...toLane.cards, newCard];
      }
      const updatedLanes = [...state.data.lanes];
      updatedLanes[fromLaneIndex] = { ...fromLane, cards: updatedFromCards };
      updatedLanes[toLaneIndex] = { ...toLane, cards: updatedToCards };
      return { data: { ...state.data, lanes: updatedLanes } };
    }),
    updateCards: (laneId, cards) => set((state) => updateLaneById(state, laneId, { cards })),
    updateCard: (laneId, card) => set((state) => {
      const laneIndex = findLaneIndex(state, laneId);
      const lane = state.data.lanes[laneIndex];
      const cardIndex = lane.cards.findIndex((c) => c.id === card.id);
      if (cardIndex === -1) {
        return state;
      }
      const updatedCards = [...lane.cards];
      updatedCards[cardIndex] = card;
      return updateLaneById(state, laneId, { cards: updatedCards });
    }),
    updateLanes: (lanes) => set((state) => ({
      data: { ...state.data, lanes }
    })),
    updateLane: (lane) => set((state) => {
      if (!lane.id) return state;
      const laneIndex = state.data.lanes.findIndex((l) => l.id === lane.id);
      if (laneIndex === -1) {
        return state;
      }
      return updateLaneById(state, lane.id, lane);
    }),
    paginateLane: (laneId, newCards, nextPage) => set((state) => {
      const updatedLanes = state.data.lanes.map(
        (l) => l.id === laneId ? { ...l, cards: [...l.cards, ...newCards], currentPage: nextPage } : l
      );
      return { data: { ...state.data, lanes: updatedLanes } };
    }),
    moveLane: (fromIndex, toIndex) => set((state) => {
      const updatedLanes = [...state.data.lanes];
      const [lane] = updatedLanes.splice(fromIndex, 1);
      updatedLanes.splice(toIndex, 0, lane);
      return { data: { ...state.data, lanes: updatedLanes } };
    }),
    removeLane: (laneId) => set((state) => {
      const updatedLanes = state.data.lanes.filter((l) => l.id !== laneId);
      return { data: { ...state.data, lanes: updatedLanes } };
    }),
    addLane: (lane) => set((state) => ({
      data: { ...state.data, lanes: [...state.data.lanes, lane] }
    }))
  };
});

const Board = ({ data, children, className, components, id, t, ...rest }) => {
  const allClassNames = className ? `react-trello-board ${className}` : "react-trello-board";
  return /* @__PURE__ */ React__default.createElement(BoardContext.Provider, { value: store }, /* @__PURE__ */ React__default.createElement(components.GlobalStyle, null), /* @__PURE__ */ React__default.createElement(
    BoardContainer,
    {
      id: id || uuid.v1(),
      data,
      components,
      t,
      className: allClassNames,
      ...rest
    }
  ));
};
const BoardContext = React.createContext(store);

const useBoard = () => {
  const store = React.useContext(BoardContext);
  return zustand.useStore(store);
};

const Lane = ({
  id,
  index,
  boardId,
  title,
  label,
  cards,
  style,
  collapsibleLanes,
  className,
  titleStyle,
  titleClassName,
  labelStyle,
  labelClassName,
  cardStyle,
  cardClassName,
  currentPage,
  draggable,
  droppable,
  editable,
  canAddLanes,
  laneSortFunction,
  hideCardDeleteIcon,
  cardDraggable,
  cardDragClass,
  cardDropClass,
  tagStyle,
  components: components2,
  onLaneScroll,
  onLaneAdd,
  onLaneDelete,
  onLaneUpdate,
  onCardClick,
  onCardAdd,
  onCardDelete,
  onCardUpdate,
  onBeforeCardDelete,
  onCardMoveAcrossLanes,
  onLaneClick,
  handleDragStart,
  handleDragEnd,
  getCardDetails,
  t,
  children,
  ...otherProps
}) => {
  const board = useBoard();
  const [loading, setLoading] = React__default.useState(false);
  const [currentPageState, setCurrentPageState] = React__default.useState(currentPage);
  const [collapsed, setCollapsed] = React__default.useState(false);
  const [addCardMode, setAddCardMode] = React__default.useState(false);
  const [isDraggingOver, setIsDraggingOver] = React__default.useState(false);
  React.useEffect(() => {
    setCurrentPageState(currentPage);
  }, [cards]);
  const sortCards = (cards2, sortFunction) => {
    if (!cards2) {
      return [];
    }
    if (!sortFunction) {
      return cards2;
    }
    return cards2.concat().sort((card1, card2) => sortFunction(card1, card2));
  };
  const addNewCard = (params) => {
    const laneId = params.laneId || id;
    const _id = uuid.v1();
    setAddCardMode(false);
    const card = { id: _id, ...params };
    board.addCard(card, laneId);
    onCardAdd?.(card, laneId);
  };
  const updateCard = (updatedCard) => {
    board.updateCard(id, updatedCard);
    onCardUpdate?.(id, updatedCard);
  };
  const updateTitle = (value) => {
    board.updateLane({ id, title: value });
    onLaneUpdate?.(id, { id, title: value });
  };
  const laneDidMount = (node) => {
    if (node) {
      node.addEventListener("scroll", handleScroll);
    }
  };
  const removeLane = () => {
    board.removeLane(id);
    onLaneDelete?.(id);
  };
  const handleScroll = (evt) => {
    const node = evt.target;
    const elemScrollPosition = node.scrollHeight - node.scrollTop - node.clientHeight;
    if (elemScrollPosition < 1 && onLaneScroll && !loading) {
      setLoading(true);
      const nextPage = currentPageState + 1;
      onLaneScroll(nextPage, id).then((moreCards) => {
        if ((moreCards || []).length > 0) {
          board.paginateLane(id, moreCards, nextPage);
        }
        setLoading(false);
      });
    }
  };
  const groupName = `TrelloBoard${boardId}Lane`;
  const handleCardClick = (e, card) => {
    onCardClick?.(card.id, card.metadata, card.laneId);
    e.stopPropagation();
  };
  const toggleLaneCollapsed = () => {
    collapsibleLanes && setCollapsed(!collapsed);
  };
  const removeCard = (cardId) => {
    if (onBeforeCardDelete && typeof onBeforeCardDelete === "function") {
      onBeforeCardDelete(() => {
        board.removeCard(id, cardId);
        onCardDelete?.(cardId, id);
      });
    } else {
      board.removeCard(id, cardId);
      onCardDelete?.(cardId, id);
    }
  };
  const onDragStart = ({ payload }) => {
    handleDragStart?.(payload.id, id);
  };
  const onDragEnd = (laneId, result) => {
    const { addedIndex, payload } = result;
    if (isDraggingOver) {
      setIsDraggingOver(false);
    }
    if (addedIndex != null) {
      const newCard = { ...payload, laneId };
      handleDragEnd?.(payload.id, laneId, id, addedIndex, newCard);
      const response = handleDragEnd ? handleDragEnd(payload.id, payload.laneId, laneId, addedIndex, newCard) : true;
      if (response === void 0 || !!response) {
        board.moveCard(payload.laneId, laneId, payload.id, addedIndex);
        onCardMoveAcrossLanes?.(payload.laneId, laneId, payload.id, addedIndex);
      }
      return response;
    }
  };
  const renderDragContainer = (isDraggingOver2) => {
    const showableCards = collapsed ? [] : cards;
    const cardList = sortCards(showableCards, laneSortFunction).map(
      (card, idx) => {
        const onDeleteCard = () => removeCard(card.id);
        const cardToRender = /* @__PURE__ */ React__default.createElement(
          components2.Card,
          {
            key: card.id,
            index: idx,
            style: card.style || cardStyle,
            className: "react-trello-card",
            onDelete: onDeleteCard,
            onClick: (e) => handleCardClick(e, card),
            onChange: (updatedCard) => updateCard(updatedCard),
            showDeleteButton: !hideCardDeleteIcon,
            tagStyle,
            cardDraggable,
            editable,
            title: card.title,
            description: card.description,
            label: card.label,
            metadata: card.metadata,
            id: card.id,
            t,
            ...card
          }
        );
        return cardDraggable && (!Object.prototype.hasOwnProperty.call(card, "draggable") || card.draggable) ? /* @__PURE__ */ React__default.createElement(Draggable, { key: card.id }, cardToRender) : /* @__PURE__ */ React__default.createElement("span", { key: card.id }, cardToRender);
      }
    );
    return /* @__PURE__ */ React__default.createElement(
      components2.ScrollableLane,
      {
        ref: laneDidMount,
        isDraggingOver: isDraggingOver2
      },
      /* @__PURE__ */ React__default.createElement(
        Container,
        {
          orientation: "vertical",
          groupName,
          dragClass: cardDragClass,
          dropClass: cardDropClass,
          onDragStart,
          onDrop: (e) => {
            onDragEnd(id, e);
          },
          onDragEnter: () => setIsDraggingOver(true),
          onDragLeave: () => setIsDraggingOver(false),
          shouldAcceptDrop: (sourceContainerOptions) => droppable && sourceContainerOptions.groupName === groupName,
          getChildPayload: (index2) => getCardDetails(id, index2)
        },
        cardList
      ),
      editable && !addCardMode && /* @__PURE__ */ React__default.createElement(components2.AddCardLink, { onClick: () => setAddCardMode(true), t }),
      addCardMode && /* @__PURE__ */ React__default.createElement(
        components2.NewCardForm,
        {
          onCancel: () => setAddCardMode(false),
          t,
          laneId: id,
          onAdd: addNewCard
        }
      )
    );
  };
  const allClassNames = className ? `react-trello-lane ${className}` : "react-trello-lane";
  const showFooter = collapsibleLanes && cards.length > 0;
  return /* @__PURE__ */ React__default.createElement(
    components2.Section,
    {
      ...otherProps,
      key: id,
      onClick: () => onLaneClick?.(id),
      draggable: false,
      className: allClassNames,
      style
    },
    /* @__PURE__ */ React__default.createElement(
      components2.LaneHeader,
      {
        onDelete: removeLane,
        onDoubleClick: toggleLaneCollapsed,
        updateTitle,
        title,
        label,
        labelStyle,
        titleStyle,
        collapsible: collapsibleLanes,
        collapsed,
        t
      }
    ),
    renderDragContainer(isDraggingOver),
    loading && /* @__PURE__ */ React__default.createElement(components2.Loader, null),
    showFooter && /* @__PURE__ */ React__default.createElement(
      components2.LaneFooter,
      {
        onClick: toggleLaneCollapsed,
        collapsed
      }
    )
  );
};

const BoardContainer = ({
  components,
  handleDragStart = () => {
  },
  handleDragEnd = () => {
  },
  handleLaneDragStart = () => {
  },
  className,
  style,
  id,
  draggable = false,
  laneDraggable = true,
  data,
  cardDragClass = "react_trello_dragClass",
  collapsibleLanes = false,
  laneDragClass = "react_trello_dragLaneClass",
  laneDropClass = "",
  onDataChange = () => {
  },
  cardDraggable = true,
  onCardAdd,
  onCardUpdate = () => {
  },
  onCardClick,
  onBeforeCardDelete,
  handleLaneDragEnd = () => {
  },
  onCardDelete,
  cardStyle,
  hideCardDeleteIcon = false,
  onLaneScroll,
  onLaneClick,
  onLaneAdd = () => {
  },
  onLaneDelete = () => {
  },
  onLaneUpdate = () => {
  },
  editable = false,
  canAddLanes = false,
  eventBusHandle,
  tagStyle,
  editLaneTitle,
  laneStyle,
  laneSortFunction,
  onCardMoveAcrossLanes = () => {
  },
  t,
  ...otherProps
}) => {
  const [addLaneMode, setAddLaneMode] = React.useState(false);
  const board = useBoard();
  React.useEffect(() => {
    board.initializeLanes(data.lanes);
    if (eventBusHandle) {
      wireEventBus();
    }
    return () => {
      board.refreshBoard([]);
    };
  }, []);
  React.useEffect(() => {
    if (JSON.stringify(board.data) !== JSON.stringify(data)) {
      onDataChange(data);
      board.initializeLanes(data.lanes);
    }
  }, [data]);
  const wireEventBus = () => {
    const eventBus = {
      publish: (event) => {
        switch (event.type) {
          case "ADD_CARD":
            return board.addCard(event.card, event.laneId, event.index);
          case "UPDATE_CARD":
            return board.updateCard(event.laneId, event.card);
          case "REMOVE_CARD":
            return board.removeCard(event.laneId, event.cardId);
          case "REFRESH_BOARD":
            return board.refreshBoard(event.data.lanes);
          case "MOVE_CARD":
            return board.moveCard(
              event.fromLaneId,
              event.toLaneId,
              event.cardId,
              event.index
            );
          case "UPDATE_CARDS":
            return board.updateCards(event.laneId, event.cards);
          case "UPDATE_LANES":
            return board.updateLanes(event.lanes);
          case "UPDATE_LANE":
            return board.updateLane(event.lane);
        }
      }
    };
    eventBusHandle(eventBus);
  };
  const getLaneDetails = (index) => {
    return board.data.lanes[index];
  };
  const getCardDetails = (laneId, cardIndex) => {
    return board.data.lanes.find((lane) => lane.id === laneId).cards[cardIndex];
  };
  const groupName = `TrelloBoard${id}`;
  return /* @__PURE__ */ React__default.createElement(components.BoardWrapper, { style, ...otherProps, draggable: false }, /* @__PURE__ */ React__default.createElement(reactPopopo.PopoverWrapper, null, /* @__PURE__ */ React__default.createElement(
    Container,
    {
      orientation: "horizontal",
      className,
      onDragStart: ({ payload }) => {
        handleLaneDragStart(payload.id);
      },
      dragClass: laneDragClass,
      dropClass: laneDropClass,
      onDrop: ({ removedIndex, addedIndex, payload }) => {
        if (removedIndex !== addedIndex) {
          board.moveLane(removedIndex, addedIndex);
          handleLaneDragEnd(removedIndex, addedIndex, payload);
        }
      },
      lockAxis: "x",
      getChildPayload: (index) => getLaneDetails(index),
      groupName
    },
    board.data.lanes.map((lane, index) => {
      const { id: id2, droppable, ...otherProps2 } = lane;
      const laneToRender = /* @__PURE__ */ React__default.createElement(
        Lane,
        {
          key: id2,
          boardId: groupName,
          components,
          id: id2,
          getCardDetails,
          index,
          droppable: droppable === void 0 ? true : droppable,
          style: laneStyle || lane.style || {},
          labelStyle: lane.labelStyle || {},
          cardStyle: cardStyle || lane.cardStyle,
          editable: editable && !lane.disallowAddingCard,
          draggable: laneDraggable,
          cardDraggable,
          onCardMoveAcrossLanes,
          onLaneScroll,
          onLaneDelete,
          onLaneUpdate,
          onCardClick,
          onBeforeCardDelete,
          onCardDelete,
          onCardAdd,
          onCardUpdate,
          onLaneClick,
          laneSortFunction,
          collapsibleLanes,
          canAddLanes,
          hideCardDeleteIcon,
          tagStyle,
          title: lane.title,
          handleDragStart,
          handleDragEnd,
          cardDragClass,
          t,
          ...otherProps2
        }
      );
      return draggable && laneDraggable ? /* @__PURE__ */ React__default.createElement(Draggable, { key: lane.id }, laneToRender) : laneToRender;
    })
  )), canAddLanes && /* @__PURE__ */ React__default.createElement(Container, { orientation: "horizontal" }, editable && !addLaneMode ? /* @__PURE__ */ React__default.createElement(
    components.NewLaneSection,
    {
      t,
      onClick: () => setAddLaneMode(true)
    }
  ) : addLaneMode && /* @__PURE__ */ React__default.createElement(
    components.NewLaneForm,
    {
      onCancel: () => setAddLaneMode(false),
      onAdd: ({ id: id2, title }) => {
        setAddLaneMode(false);
        board.addLane({ id: id2, title, cards: [] });
        onLaneAdd({
          laneId: id2,
          title,
          description: "",
          label: ""
        });
      },
      t
    }
  )));
};

const REPLACE_TABLE = {
  addCardLink: "components.Card",
  customLaneHeader: "components.LaneHeader",
  newLaneTemplate: "components.NewLaneSection",
  newCardTemplate: "components.NewCardForm",
  children: "components.Card",
  customCardLayout: "components.Card",
  addLaneTitle: '`t` function with key "Add another lane"'
  // addCardLink: '`t` function with key "Click to add card"'
};
const warn = (prop) => {
  const use = REPLACE_TABLE[prop];
  console.warn(
    `react-trello property '${prop}' is removed. Use '${use}' instead. More - https://github.com/rcdexta/react-trello/blob/master/UPGRADE.md`
  );
};
const deprecationWarnings = (props) => {
  for (const key in REPLACE_TABLE) {
    if (Object.prototype.hasOwnProperty.call(REPLACE_TABLE, key)) {
      warn(key);
    } else {
      console.warn(`react-trello property '${key}' is removed`);
    }
  }
};

const button$1 = {
	"Add lane": "Add lane",
	"Add card": "Add card",
	Cancel: "Cancel"
};
const placeholder$1 = {
	title: "title",
	description: "description",
	label: "label"
};
const eng = {
	"Add another lane": "+ Add another lane",
	"Click to add card": "Click to add card",
	"Delete lane": "Delete lane",
	"Lane actions": "Lane actions",
	button: button$1,
	placeholder: placeholder$1
};

const button = {
	"Add card": "Добавить карту",
	"Add lane": "Добавить колонку",
	Cancel: "Отменить"
};
const placeholder = {
	title: "Название",
	description: "Описание",
	label: "Метка"
};
const rus = {
	"Add another lane": "＋Добавить колонку",
	"Click to add card": "＋Добавить карточку",
	"Delete lane": "Удалить колонку",
	"Lane actions": "Действия над колонкой",
	button: button,
	placeholder: placeholder
};

const locales = {
  en: {
    translation: eng
  },
  ru: {
    translation: rus
  }
};

const getValue = (table) => (key) => {
  const keys = key.includes(".") ? key.split(".") : [key];
  let value = table;
  for (const k of keys) {
    if (value && k in value) {
      value = value[k];
    } else {
      return void 0;
    }
  }
  return value;
};
const createTranslate = (table) => (key) => getValue(table)(key);

const DEFAULT_LANG = "en";
function DefaultBoard({
  components,
  lang = DEFAULT_LANG,
  ...otherProps
}) {
  deprecationWarnings();
  const translate = createTranslate(locales[lang || "en"].translation);
  return /* @__PURE__ */ React__default.createElement(
    Board,
    {
      t: translate,
      components: { ...DefaultComponents, ...components },
      ...otherProps
    }
  );
}

exports.BoardContainer = BoardContainer;
exports.Container = Container;
exports.DeleteButton = DeleteButton;
exports.Draggable = Draggable;
exports.EditableLabel = EditableLabel;
exports.InlineInput = InlineInput;
exports.Lane = Lane;
exports.components = DefaultComponents;
exports.createTranslate = createTranslate;
exports.default = DefaultBoard;
exports.locales = locales;
