import React, { FC, PropsWithChildren, HTMLAttributes, CSSProperties, Component, ReactElement } from 'react';
import * as styled_components from 'styled-components';
import { ThemedStyledFunction } from 'styled-components';

declare const GlobalStyle: styled_components.GlobalStyleComponent<{}, styled_components.DefaultTheme>;
declare const BoardWrapper: styled_components.StyledComponent<"div", any, {}, never>;
declare const Section: styled_components.StyledComponent<"section", any, {}, never>;
declare const ScrollableLane: styled_components.StyledComponent<"div", any, {
    isDraggingOver?: boolean;
}, never>;

interface AddCardLinkProps extends HTMLAttributes<HTMLAnchorElement | HTMLButtonElement> {
    t: typeof _default$1;
}
declare const AddCardLink: FC<PropsWithChildren<AddCardLinkProps>>;

interface BoardData {
    lanes: Lane$1[];
}
interface Lane$1 {
    id: string;
    title?: string;
    label?: string;
    style?: CSSProperties;
    cards?: Card$1[];
    currentPage?: number;
    droppable?: boolean;
    labelStyle?: CSSProperties;
    cardStyle?: CSSProperties;
    disallowAddingCard?: boolean;
    [key: string]: any;
}
interface Card$1 {
    id: string;
    title?: string;
    label?: string;
    description?: string;
    laneId?: string;
    style?: CSSProperties;
    draggable?: boolean;
    [key: string]: any;
}

interface TagProps {
    title: string;
    color?: string;
    bgcolor?: string;
    tagStyle?: CSSProperties;
}

/**
 * Card component type
 *
 * Pass in a type to the optional generic to add custom properties to the card
 *
 * @example
 *
 * type CustomCardProps = {
 * 	dueOn: string;
 * }
 *
 * const CustomCard: CardComponent<CustomCardProps> = ({ dueOn, ...props }) => {
 * 	return (
 * 		<Card {...props}>
 * 			<Detail>{dueOn}</Detail>
 * 		</Card>
 * 	)
 * }
 */
type CardComponent<TCustomCardProps extends {} = object> = FC<PropsWithChildren<CardProps & TCustomCardProps>>;
type CardProps = {
    showDeleteButton?: boolean;
    onDelete?: () => void;
    onClick?: (e: any) => void;
    onChange?: (card: Card$1) => void;
    style?: CSSProperties;
    tagStyle?: CSSProperties;
    className?: string;
    id: string;
    index: number;
    title?: string;
    label?: string;
    description?: string;
    tags?: TagProps[];
    cardDraggable?: boolean;
    editable?: boolean;
    metadata?: Record<string, any>;
    t: typeof _default$1;
};
declare const Card: CardComponent;

type LaneFooterComponent = FC<PropsWithChildren<LaneFooterProps>>;
interface LaneFooterProps extends HTMLAttributes<HTMLDivElement> {
    collapsed?: boolean;
}
declare const LaneFooter: LaneFooterComponent;

declare const _default$1: (table: any) => (key: any) => any;

type LaneHeaderProps = _LaneHeaderProps & {
    [key: string]: any;
};
interface _LaneHeaderProps extends HTMLAttributes<HTMLHeadElement> {
    updateTitle?: (title: string) => void;
    canAddLanes?: boolean;
    onDelete?: () => void;
    editLaneTitle?: boolean;
    label?: string;
    titleStyle?: CSSProperties;
    labelStyle?: CSSProperties;
    laneDraggable?: boolean;
    t: typeof _default$1;
}
declare const LaneHeader: FC<PropsWithChildren<LaneHeaderProps>>;

declare const Loader: () => React.JSX.Element;

interface FormState {
    title: string;
    description: string;
    label: string;
    laneId: string;
}
interface NewCardFormProps {
    laneId: string;
    onCancel: () => void;
    onAdd: (formState: FormState) => void;
    t: typeof _default$1;
}
declare const NewCardForm: FC<NewCardFormProps>;

interface NewLaneFormProps extends HTMLAttributes<ThemedStyledFunction<"section", object, object, never>> {
    onCancel: () => void;
    onAdd: ({ id, title }: {
        id: string;
        title: string;
    }) => void;
    t: typeof _default$1;
}
declare const NewLaneForm: FC<PropsWithChildren<NewLaneFormProps>>;

declare const NewLaneSection: FC<PropsWithChildren<{
    t: typeof _default$1;
    onClick: () => void;
}>>;

declare const components_AddCardLink: typeof AddCardLink;
declare const components_BoardWrapper: typeof BoardWrapper;
declare const components_Card: typeof Card;
declare const components_GlobalStyle: typeof GlobalStyle;
declare const components_LaneFooter: typeof LaneFooter;
declare const components_LaneHeader: typeof LaneHeader;
declare const components_Loader: typeof Loader;
declare const components_NewCardForm: typeof NewCardForm;
declare const components_NewLaneForm: typeof NewLaneForm;
declare const components_NewLaneSection: typeof NewLaneSection;
declare const components_ScrollableLane: typeof ScrollableLane;
declare const components_Section: typeof Section;
declare namespace components {
  export { components_AddCardLink as AddCardLink, components_BoardWrapper as BoardWrapper, components_Card as Card, components_GlobalStyle as GlobalStyle, components_LaneFooter as LaneFooter, components_LaneHeader as LaneHeader, components_Loader as Loader, components_NewCardForm as NewCardForm, components_NewLaneForm as NewLaneForm, components_NewLaneSection as NewLaneSection, components_ScrollableLane as ScrollableLane, components_Section as Section };
}

interface EventBusHandle {
    publish: (event: EventBusEvent) => any;
}
type EventBusEvent = {
    type: "ADD_CARD";
    laneId: string;
    card: Card$1;
    index?: number;
} | {
    type: "UPDATE_CARD";
    laneId: string;
    card: Card$1;
} | {
    type: "REMOVE_CARD";
    laneId: string;
    cardId: string;
} | {
    type: "REFRESH_BOARD";
    data: BoardData;
} | {
    type: "MOVE_CARD";
    fromLaneId: string;
    toLaneId: string;
    cardId: string;
    index: number;
} | {
    type: "UPDATE_CARDS";
    laneId: string;
    cards: Card$1[];
} | {
    type: "UPDATE_LANES";
    lanes: BoardData["lanes"];
} | {
    type: "UPDATE_LANE";
    laneId: string;
    lane: Lane$1;
};

interface BoardContainerProps {
    id?: string;
    components?: Partial<typeof components>;
    className?: string;
    data: BoardData;
    reducerData?: BoardData;
    onDataChange?: (reducerData: BoardData) => void;
    eventBusHandle?: (handle: EventBusHandle) => void;
    onLaneScroll?: (requestedPage: any, laneId: any) => Promise<unknown>;
    onCardClick?: (cardId: Card$1["id"], metadata: {
        id: string;
    }, card: Card$1) => void;
    onBeforeCardDelete?: () => void;
    onCardDelete?: (cardId: string, laneId: string) => void;
    onCardAdd?: (card: Card$1, laneId: string) => void;
    onCardUpdate?: (cardId: string, data: Card$1) => void;
    onLaneAdd?: (laneAddParams: FormState) => void;
    onLaneDelete?: () => void;
    onLaneClick?: (laneId: string) => void;
    onLaneUpdate?: (laneId: string, data: Lane$1) => void;
    laneSortFunction?: (cardA: Card$1, cardB: Card$1) => number;
    draggable?: boolean;
    collapsibleLanes?: boolean;
    editable?: boolean;
    canAddLanes?: boolean;
    hideCardDeleteAction?: boolean;
    hideCardDeleteIcon?: boolean;
    handleDragStart?: (cardId: string, laneId: string) => void;
    handleDragEnd?: (cardId: Card$1["id"], sourceLandId: Lane$1["id"], targetLaneId: Lane$1["id"], position: number, card: Card$1) => void;
    handleLaneDragStart?: (payloadId: string) => void;
    handleLaneDragEnd?: (removedIndex: string, addedIndex: string, payload: Lane$1) => void;
    style?: CSSProperties;
    tagStyle?: CSSProperties;
    laneStyle?: CSSProperties;
    cardStyle?: CSSProperties;
    laneDraggable?: boolean;
    cardDraggable?: boolean;
    cardDragClass?: string;
    laneDragClass?: string;
    laneDropClass?: string;
    editLaneTitle?: boolean;
    onCardMoveAcrossLanes?: (fromLaneId: string, toLaneId: string, cardId: string, addedIndex: string) => void;
    t?: typeof _default$1;
}
declare const BoardContainer: FC<PropsWithChildren<BoardContainerProps>>;

interface LaneProps {
    id: string;
    index?: number;
    boardId?: string;
    title?: string;
    label?: string;
    cards?: any[];
    style?: any;
    collapsibleLanes?: boolean;
    className?: string;
    titleStyle?: any;
    titleClassName?: string;
    labelStyle?: any;
    labelClassName?: string;
    cardStyle?: any;
    cardClassName?: string;
    currentPage?: number;
    draggable?: boolean;
    droppable?: boolean;
    editable?: boolean;
    canAddLanes?: boolean;
    laneSortFunction?: (cardA: Card$1, cardB: Card$1) => number;
    hideCardDeleteIcon?: boolean;
    cardDraggable?: boolean;
    cardDragClass?: string;
    cardDropClass?: string;
    tagStyle?: CSSProperties;
    components?: Partial<typeof components>;
    onLaneScroll?: (page: number, laneId: string) => Promise<unknown>;
    onLaneAdd?: (params: any) => void;
    onLaneDelete?: (laneId: string) => void;
    onLaneUpdate?: (laneId: string, data: Lane$1) => void;
    onCardClick?: (cardId: string, metadata: {
        id: string;
    }, card: Card$1) => void;
    onCardAdd?: (card: any, laneId: string) => void;
    onCardDelete?: (cardId: string, laneId: string) => void;
    onCardUpdate?: (laneId: string, card: any) => void;
    onBeforeCardDelete?: (callback: () => void) => void;
    onCardMoveAcrossLanes?: (fromLaneId: string, toLaneId: string, cardId: string, index: string) => void;
    onLaneClick?: (laneId: string) => void;
    handleDragStart?: (cardId: string, laneId: string) => void;
    handleDragEnd?: (cardId: string, payloadLaneId: string, laneId: string, addedIndex: number, newCard: Card$1) => void;
    getCardDetails?: (laneId: string, cardIndex: number) => any;
    t?: typeof _default$1;
}
declare const Lane: FC<PropsWithChildren<LaneProps>>;

interface ContainerProps {
    behaviour?: "move" | "copy" | "drag-zone";
    groupName?: string;
    orientation?: "horizontal" | "vertical";
    style?: object;
    dragHandleSelector?: string;
    className?: string;
    nonDragAreaSelector?: string;
    dragBeginDelay?: number;
    animationDuration?: number;
    autoScrollEnabled?: string;
    lockAxis?: string;
    dragClass?: string;
    dropClass?: string;
    onDragStart?: (params: any) => void;
    onDragEnd?: (laneId: string, result: {
        addedIndex: any;
        payload: any;
    }) => void;
    onDrop?: (params: any) => void;
    onDropReady?: (params: any) => void;
    getChildPayload?: (index: number) => any;
    shouldAnimateDrop?: (params: any) => boolean;
    shouldAcceptDrop?: (params: any) => boolean;
    onDragEnter?: (params: any) => void;
    onDragLeave?: (params: any) => void;
    render?: (params: any) => any;
    getGhostParent?: () => any;
    removeOnDropOut?: boolean;
}
declare class Container extends Component<ContainerProps> {
    containerDiv: typeof Container | Element | Text;
    prevContainer: typeof Container | Element | Text;
    container: any;
    constructor(props: any);
    componentDidMount(): void;
    componentWillUnmount(): void;
    componentDidUpdate(): void;
    render(): any;
    setRef(element: any): void;
    getContainerOptions(): Readonly<ContainerProps> & Readonly<{
        children?: React.ReactNode | undefined;
    }> & Pick<ContainerProps, "onDragEnd" | "onDragEnter" | "onDragLeave" | "onDragStart" | "onDrop" | "render" | "onDropReady" | "getChildPayload" | "shouldAnimateDrop" | "shouldAcceptDrop" | "getGhostParent">;
}

declare class Draggable extends Component<{
    render?: () => ReactElement;
    className?: string;
}> {
    render(): React.JSX.Element;
}

declare const _default: {
    en: {
        translation: {
            "Add another lane": string;
            "Click to add card": string;
            "Delete lane": string;
            "Lane actions": string;
            button: {
                "Add lane": string;
                "Add card": string;
                Cancel: string;
            };
            placeholder: {
                title: string;
                description: string;
                label: string;
            };
        };
    };
    ru: {
        translation: {
            "Add another lane": string;
            "Click to add card": string;
            "Delete lane": string;
            "Lane actions": string;
            button: {
                "Add card": string;
                "Add lane": string;
                Cancel: string;
            };
            placeholder: {
                title: string;
                description: string;
                label: string;
            };
        };
    };
};

type DeleteButtonProps = HTMLAttributes<HTMLDivElement>;
declare const DeleteButton: FC<PropsWithChildren<DeleteButtonProps>>;

interface EditableLabelProps {
    onChange?: (labelText: string) => void;
    placeholder?: string;
    autoFocus?: boolean;
    inline?: boolean;
    value?: string;
}
declare const EditableLabel: FC<PropsWithChildren<EditableLabelProps>>;

interface InlineInputProps {
    onSave?: (inputValue: string) => void;
    onCancel?: () => void;
    border?: boolean;
    placeholder?: string;
    value?: string;
    autoFocus?: boolean;
    resize?: "none" | "vertical" | "horizontal";
}
declare const InlineInput: FC<InlineInputProps>;

declare function DefaultBoard({ components, lang, ...otherProps }: BoardContainerProps & {
    lang?: keyof typeof _default;
}): React.JSX.Element;

export { BoardContainer, Container, DeleteButton, Draggable, EditableLabel, InlineInput, Lane, components, _default$1 as createTranslate, DefaultBoard as default, _default as locales };
